@@ -1,11 +1,10 @@
 import logging
 import os
 import posixpath
+from urllib.parse import urlparse
 
-from dvc.config import Config
-from dvc.config import ConfigError
+from dvc.config import Config, ConfigError
 from dvc.utils import relpath
-from dvc.utils.compat import urlparse
 
 
 logger = logging.getLogger(__name__)
@@ -134,6 +133,9 @@ class RemoteConfig(object):
                 break
 
     def modify(self, name, option, value, level=None):
+        # try to get remote settings to verify that section exists
+        self.get_settings(name)
+
         self.config.set(
             Config.SECTION_REMOTE_FMT.format(name), option, value, level=level
         )
