@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from . import locked
 
 
@@ -23,5 +21,5 @@ def push(
         remote=remote,
         jobs=jobs,
         recursive=recursive,
-    )["local"]
+    )
     return self.cloud.push(used, jobs, remote=remote)
